@@ -171,8 +171,8 @@ def main():
 
     # now try to download all the artifacts and check their versions
     # this list should visit kernels in order from newest to oldest.
-    URL_BLEEDING = 'https://ci.betrusted.io/releases/latest/'
-    URL_STABLE = 'https://ci.betrusted.io/latest-ci/'
+    URL_STABLE = 'https://ci.betrusted.io/releases/latest/'
+    URL_BLEEDING = 'https://ci.betrusted.io/latest-ci/'
     print("Phase 1: Download the update")
     if args.bleeding_edge:
         print("Bleeding edge CI build selected")
@@ -217,7 +217,8 @@ def main():
             ['prog', "Uploading kernel", locs['LOC_KERNEL'][0], kernel],
             ['prog', "Uploading EC", locs['LOC_EC'][0], ec_fw],
             ['prog', "Uploading wf200", locs['LOC_WF200'][0], wf200],
-            ['prog', "Overwriting gateware", locs['LOC_SOC'][0], soc_csr],
+            ['prog', "Overwriting boot gateware", locs['LOC_SOC'][0], soc_csr],
+            ['erase', "Erasing any staged gateware", locs['LOC_STAGING'][0], 0x28_0000],
         ]
         if args.paranoid:
             # erase the entire area -- about 10-15 minutes
@@ -294,7 +295,7 @@ def main():
 
     print("\nUpdate finished!\n")
     print("{}\nVisit the QR code above to help locate the hole, or go to https://ci.betrusted.io/i/reset.jpg.".format(QR_CODE))
-    print("Reboot by inserting a paperclip in the hole in the lower right hand side, then follow the on-device instructions.")
+    print("You *must* reboot by inserting a paperclip in the hole in the lower right hand side, then follow the on-device instructions.")
 
 
 def auto_int(x):
